==> kubernetes-model-core-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ResourceRequirementsBuilder extends ResourceRequirementsFluentImpl<ResourceRequirementsBuilder> implements VisitableBuilder<ResourceRequirements,ResourceRequirementsBuilder>{
  public ResourceRequirementsBuilder() {
    this(false);
  }
  public ResourceRequirementsBuilder(Boolean validationEnabled) {
    this(new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance) {
    this(fluent, instance, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLimits(instance.getLimits()); 
    fluent.withRequests(instance.getRequests()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance) {
    this(instance,false);
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLimits(instance.getLimits()); 
    this.withRequests(instance.getRequests()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ResourceRequirementsFluent<?> fluent;
  Boolean validationEnabled;
  public ResourceRequirements build() {
    ResourceRequirements buildable = new ResourceRequirements(fluent.getLimits(),fluent.getRequests());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ResourceRequirementsBuilder extends ResourceRequirementsFluentImpl<ResourceRequirementsBuilder> implements VisitableBuilder<ResourceRequirements,ResourceRequirementsBuilder>{
  public ResourceRequirementsBuilder() {
    this(false);
  }
  public ResourceRequirementsBuilder(Boolean validationEnabled) {
    this(new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance) {
    this(fluent, instance, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withClaims(instance.getClaims()); 
    fluent.withLimits(instance.getLimits()); 
    fluent.withRequests(instance.getRequests()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance) {
    this(instance,false);
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withClaims(instance.getClaims()); 
    this.withLimits(instance.getLimits()); 
    this.withRequests(instance.getRequests()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ResourceRequirementsFluent<?> fluent;
  Boolean validationEnabled;
  public ResourceRequirements build() {
    ResourceRequirements buildable = new ResourceRequirements(fluent.getClaims(),fluent.getLimits(),fluent.getRequests());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
